@@ -131,6 +131,7 @@ load_nc <- function(nc, fgs, bps, select_groups,
   if (length(search_clean) == 0) return(0)
 
   at_data <- list()
+  # At some point should update this with https://github.com/gaborcsardi/progress
   # Initialise progress par!
   # if (report) pb <- txtProgressBar(min = 0, max = length(search_clean), style = 3)
   if (report) pb <- dplyr::progress_estimated(length(search_clean))
@@ -148,7 +149,11 @@ load_nc <- function(nc, fgs, bps, select_groups,
   # Get final species and number of ageclasses per species
   final_species <- select_groups[sapply(lapply(select_groups, grepl, x = search_clean), any)]
   id <- sapply(final_species, function(x) which(x == fgs$Name))
-  final_agecl <- fgs$NumCohorts[id] * fgs$NumGeneTypes[id]
+  if ("NumGeneTypes" %in% names(fgs)) {
+    final_agecl <- fgs$NumCohorts[id] * fgs$NumGeneTypes[id]
+  } else {
+    final_agecl <- fgs$NumCohorts[id]
+  }
 
   # This may allow init files to be loaded as well! Unfortunately "num_layers" is missing in
   # the init file. Therefore we also load in the general file to extract the layers!
